dtls_connect

Function dtls_connect 

pub unsafe extern "C" fn dtls_connect(
    ctx: *mut dtls_context_t,
    dst: *const session_t,
) -> c_int
Establishes a DTLS channel with the specified remote peer @p dst. This function returns @c 0 if that channel already exists, a value greater than zero when a new ClientHello message was sent, and a value less than zero on error.

@param ctx The DTLS context to use. @param dst The remote party to connect to. @return A value less than zero on error, greater or equal otherwise.