pub unsafe extern "C" fn dtls_free_context(ctx: *mut dtls_context_t)Expand description
Releases any storage that has been allocated for \p ctx.
pub unsafe extern "C" fn dtls_free_context(ctx: *mut dtls_context_t)Releases any storage that has been allocated for \p ctx.