pub unsafe extern "C" fn dtls_new_context(
app_data: *mut c_void,
) -> *mut dtls_context_tExpand description
Creates a new context object. The storage allocated for the new object must be released with dtls_free_context().
pub unsafe extern "C" fn dtls_new_context(
app_data: *mut c_void,
) -> *mut dtls_context_tCreates a new context object. The storage allocated for the new object must be released with dtls_free_context().