dtls_writev

Function dtls_writev 

pub unsafe extern "C" fn dtls_writev(
    ctx: *mut dtls_context_t,
    session: *mut session_t,
    buf_array: *mut *mut uint8,
    buf_len_array: *mut usize,
    buf_array_len: usize,
) -> c_int
Writes the application data given in multiple buffers to the peer specified by @p session.

@param ctx The DTLS context to use. @param session The remote transport address and local interface. @param buf_array Array of buffers with the data to write. @param buf_len_array The length of the arrays in @p buf_array. @param buf_array_len The number of data arrays.

@return The number of bytes written, @c -1 on error or @c 0 if the peer already exists but is not connected yet.