#[repr(C)]
pub struct dtls_security_parameters_t { pub compression: dtls_compression_t, pub cipher: dtls_cipher_t, pub epoch: u16, pub rseq: u64, pub key_block: [uint8; 40], pub cseq: seqnum_t, }

Fields

compression: dtls_compression_t

< compression method

cipher: dtls_cipher_t

< cipher type

epoch: u16

< counter for cipher state changes

rseq: u64

< sequence number of last record sent

key_block: [uint8; 40]

The key block generated from PRF applied to client and server random bytes. The actual size is given by the selected cipher and can be calculated using dtls_kb_size(). Use \c dtls_kb_ macros to access the components of the key block.

cseq: seqnum_t

<sequence number of last record received