pub unsafe extern "C" fn dtls_hmac_finalize(
ctx: *mut dtls_hmac_context_t,
result: *mut c_uchar,
) -> c_intExpand description
Completes the HMAC generation and writes the result to the given output parameter \c result. The buffer must be large enough to hold the message digest created by the actual hash function. If in doubt, use \c DTLS_HMAC_MAX. The function returns the number of bytes written to \c result.
\param ctx The HMAC context. \param result Output parameter where the MAC is written to. \return Length of the MAC written to \p result.